==> print-manager-4.10.0.tar.xz: print-manager-4.10.0/add-printer/ChooseSocket.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef CHOOSE_SOCKET_H
#define CHOOSE_SOCKET_H

#include "GenericPage.h"

namespace Ui {
    class ChooseSocket;
}
class ChooseSocket : public GenericPage
{
    Q_OBJECT
public:
    ChooseSocket(QWidget *parent = 0);
    ~ChooseSocket();

    void setValues(const QVariantHash &args);
    QVariantHash values() const;
    bool isValid() const;
    bool canProceed() const;

private slots:
    void on_addressLE_textChanged(const QString &text);

private:
    Ui::ChooseSocket *ui;
    bool m_isValid;
};

#endif

==> print-manager_4.14.2.orig.tar.xz: print-manager-4.14.2/add-printer/ChooseSocket.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Daniel Nicoletti                                *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef CHOOSE_SOCKET_H
#define CHOOSE_SOCKET_H

#include "GenericPage.h"

namespace Ui {
    class ChooseSocket;
}
class ChooseSocket : public GenericPage
{
    Q_OBJECT
public:
    explicit ChooseSocket(QWidget *parent = 0);
    ~ChooseSocket();

    void setValues(const QVariantHash &args);
    QVariantHash values() const;
    bool isValid() const;
    bool canProceed() const;

private slots:
    void on_addressLE_textChanged(const QString &text);

private:
    Ui::ChooseSocket *ui;
    bool m_isValid;
};

#endif
